Learn R Programming

evolqg (version 0.2-2)

CalcR2CvCorrected: Corrected integration value

Description

Calculates the Young correction for integration, using bootstrap resampling

Usage

CalcR2CvCorrected(ind.data, ...)

## S3 method for class 'default': CalcR2CvCorrected(ind.data, cv.level = 0.06, iterations = 1000, parallel = FALSE, ...)

## S3 method for class 'lm': CalcR2CvCorrected(ind.data, cv.level = 0.06, iterations = 1000, ...)

Arguments

ind.data
Matrix of indiviual measurments, or ajusted linear model
...
aditional arguments passed to other methods
cv.level
Coeficient of variation level choosen for integration index ajustment in linear model. Defaults to 0.06.
iterations
Number of resamples to take
parallel
if TRUE computations are done in parallel. Some foreach backend must be registered, like doParallel or doMC.

Value

  • List with adjusted integration indexes, fitted models and simulated distributions of integration indexes and mean coeficient of variation.

References

Young, N. M., Wagner, G. P., and Hallgrimsson, B. (2010). Development and the evolvability of human limbs. Proceedings of the National Academy of Sciences of the United States of America, 107(8), 3400-5. doi:10.1073/pnas.0911856107

See Also

MeanMatrixStatistics, CalcR2

Examples

Run this code
integration.dist = CalcR2CvCorrected(iris[,1:4])

#adjusted values
integration.dist[[1]]

#ploting models
library(ggplot2)
ggplot(integration.dist$dist, aes(r2, mean_cv)) + geom_point() + 
       geom_smooth(method = 'lm', color= 'black') + theme_bw()
       
ggplot(integration.dist$dist, aes(eVals_cv, mean_cv)) + geom_point() + 
       geom_smooth(method = 'lm', color= 'black') + theme_bw()

Run the code above in your browser using DataLab