Learn R Programming

evolqg (version 0.1-7)

ComparisonMap: Generic Comparison Map functions for creating parallel list methods Internal functions for making eficient comparisons.

Description

Generic Comparison Map functions for creating parallel list methods Internal functions for making eficient comparisons.

Usage

ComparisonMap(matrix.list, MatrixCompFunc, ..., repeat.vector = NULL,
  parallel = FALSE)

Arguments

matrix.list
list of matrices being compared
MatrixCompFunc
Function used to compare pair of matrices, must output a vector: comparisons and probabilities
...
Aditional arguments to MatrixCompFunc
repeat.vector
Vector of repeatabilities for correlation correction.
parallel
if TRUE computations are done in parallel. Some foreach backend must be registered, like doParallel or doMC.

Value

  • Matrix of comparisons, matrix of probabilities.

See Also

MantelCor, KrzCor,RandomSkewers