Learn R Programming

evolqg (version 0.2-2)

LinearParsimony: Estimation of Linear Parcimony ancestral stated for multivariate continous traits

Description

Wagner optimization

Usage

LinearParsimony(tree, tip_means, ...)

Arguments

tree
phylogenetic tree
tip_means
list of tip nodes data. Expects one vector for each terminal.
...
aditional arguments for phytools::fastAnc

Value

  • list with calculated ancestral states, using labels or numbers from tree

Examples

Run this code
data(dentus)
data(dentus.tree)
mean.list <- dlply(dentus, .(species), numcolwise(mean))
names(mean.list) <- dentus.tree$tip.label
evolqg:::LinearParsimony(dentus.tree, mean.list)

Run the code above in your browser using DataLab