Learn R Programming

evolqg (version 0.2-2)

MonteCarloR2: R2 confidence intervals by parametric sampling

Description

Using a multivariate normal model, random populations are generated using the suplied covariance matrix. R2 is calculated on all the random population, provinding a distribution based on the original matrix.

Usage

MonteCarloR2(cov.matrix, sample.size, iterations = 1000, parallel = FALSE)

Arguments

cov.matrix
Covariance matrix.
sample.size
Size of the random populations
iterations
Number of random populations
parallel
if TRUE computations are done in parallel. Some foreach backend must be registered, like doParallel or doMC.

Value

  • returns a vector with the R2 for all populations

Details

Since this function uses multivariate normal model to generate populations, only covariance matrices should be used.

See Also

BootstrapRep, AlphaRep

Examples

Run this code
r2.dist <- MonteCarloR2(RandomMatrix(10, 1, 1, 10), 30)
quantile(r2.dist)

Run the code above in your browser using DataLab