Learn R Programming

evolqg (version 0.1-7)

OverlapDist: Distribution overlap distance

Description

Calculates the overlap between two normal distributions, defined as the probability that a draw from one distribution comes from the other

Usage

OverlapDist(cov.x, cov.y, iterations = 10000)

Arguments

cov.x
covariance or correlation matrix
cov.y
covariance or correlation matrix
iterations
number of drows

Value

  • Overlap distance between cov.x and cov.y

References

Ovaskainen, O. (2008). A Bayesian framework for comparative quantitative genetics. Proceedings of the Royal Society B, 669-678. doi:10.1098/rspb.2007.0949