Learn R Programming

evolqg (version 0.1-7)

PCAsimilarity: Compare matrices using PCA similarity factor

Description

Compare matrices using PCA similarity factor

Usage

PCAsimilarity(cov.x, cov.y, ...)

## S3 method for class 'default': PCAsimilarity(cov.x, cov.y, ret.dim = NULL, ...)

## S3 method for class 'list': PCAsimilarity(cov.x, cov.y = NULL, ..., repeat.vector = NULL, parallel = FALSE)

Arguments

cov.x
Single covariance matrix ou list of covariance matrices. If cov.x is a single matrix, it is compared to cov.y. If cov.x is a list and no cov.y is suplied, all matrices are compared to each other. If cov.x is a list and cov.y is suplied, all matrices in co
cov.y
First argument is compared to cov.y.
...
aditional arguments passed to other methods
ret.dim
number of retained dimensions in the comparison. Defaults to all.
repeat.vector
Vector of repeatabilities for correlation correction.
parallel
if TRUE computations are done in parallel. Some foreach backend must be registered, like doParallel or doMC.

Value

  • Ratio of projected variance to total variance

References

Singhal, A. and Seborg, D. E. (2005), Clustering multivariate time-series data. J. Chemometrics, 19: 427-438. doi: 10.1002/cem.945

See Also

KrzProjection,KrzCor,RandomSkewers,MantelCor

Examples

Run this code
c1 <- RandomMatrix(10)
c2 <- RandomMatrix(10)
PCAsimilarity(c1, c2)

m.list <- RandomMatrix(10, 3)
PCAsimilarity(m.list)

PCAsimilarity(m.list, c1)

Run the code above in your browser using DataLab