Learn R Programming

evolqg (version 0.2-2)

RemoveSize: Remove Size Variation

Description

Removes first principal component effect in a covariance matrix.

Usage

RemoveSize(cov.matrix)

Arguments

cov.matrix
Covariance matrix

Value

  • Altered covariance matrix with no variation on former first principal component

Details

Function sets the first eigen value to zero.

Examples

Run this code
cov.matrix <- RandomMatrix(10, 1, 1, 10)
no.size.cov.matrix <- RemoveSize(cov.matrix)
eigen(cov.matrix)
eigen(no.size.cov.matrix)

Run the code above in your browser using DataLab