MultivDriftTest: Multivariate genetic drift test for 2 populations
Description
This function estimates populations evolving through drift from an ancestral
population, given an effective population size, number of generations separating
them and the ancestral G-matrix. It calculates the magnitude of morphological
divergence expected and compare it to the observed magnitude of morphological
change.
dataframe with original measurements for the ancestral population
population2
dataframe with original measurements for the derived population
G
ancestral G matrix
Ne
effective population size esitmated for the populations
generations
time in generations separating both populations
iterations
number of simulations to perform
Value
list with the 95drift and the range of the observed magnitude of morphological change
References
Hohenlohe, P.A ; Arnold, S.J. (2008). MIPod: a hypothesis testing framework for
microevolutionary inference from patterns of divergence.
American Naturalist, 171(3),
366-385. doi: 10.1086/527498